@@ -24,14 +24,25 @@ if TYPE_CHECKING:
     from typing import BinaryIO, Tuple, List, Dict
 
 from oc_ocdm.counter_handler.counter_handler import CounterHandler
+from oc_ocdm.support.support import is_string_empty
 
 
 class FilesystemCounterHandler(CounterHandler):
-    initial_line_len: int = 3
-    trailing_char: str = " "
+    """A concrete implementation of the ``CounterHandler`` interface that persistently stores
+    the counter values within the filesystem."""
+
+    _initial_line_len: int = 3
+    _trailing_char: str = " "
 
     def __init__(self, info_dir: str) -> None:
-        if info_dir is None or len(info_dir) <= 0:
+        """
+        Constructor of the ``FilesystemCounterHandler`` class.
+
+        :param info_dir: The path to the folder that does/will contain the counter values.
+        :type info_dir: str
+        :raises ValueError: if ``info_dir`` is None or an empty string.
+        """
+        if info_dir is None or is_string_empty(info_dir):
             raise ValueError("info_dir parameter is required!")
 
         if info_dir[-1] != os.sep:
@@ -48,36 +59,83 @@ class FilesystemCounterHandler(CounterHandler):
 
     def set_counter(self, new_value: int, entity_short_name: str, prov_short_name: str = "",
                     identifier: int = 1) -> None:
+        """
+        It allows to set the counter value of graph and provenance entities.
+
+        :param new_value: The new counter value to be set
+        :type new_value: int
+        :param entity_short_name: The short name associated either to the type of the entity itself
+         or, in case of a provenance entity, to the type of the relative graph entity.
+        :type entity_short_name: str
+        :param prov_short_name: In case of a provenance entity, the short name associated to the type
+         of the entity itself. An empty string otherwise.
+        :type prov_short_name: str
+        :param identifier: In case of a provenance entity, the counter value that identifies the relative
+          graph entity. The integer value '1' otherwise.
+        :type identifier: int
+        :raises ValueError: if ``new_value`` is a negative integer or ``identifier`` is less than or equal to zero.
+        :return: None
+        """
         if new_value < 0:
             raise ValueError("new_value must be a non negative integer!")
 
         if prov_short_name == "se":
-            file_path: str = self.get_prov_path(entity_short_name)
+            file_path: str = self._get_prov_path(entity_short_name)
         else:
-            file_path: str = self.get_info_path(entity_short_name)
+            file_path: str = self._get_info_path(entity_short_name)
         self._set_number(new_value, file_path, identifier)
 
     def read_counter(self, entity_short_name: str, prov_short_name: str = "", identifier: int = 1) -> int:
+        """
+        It allows to read the counter value of graph and provenance entities.
+
+        :param entity_short_name: The short name associated either to the type of the entity itself
+         or, in case of a provenance entity, to the type of the relative graph entity.
+        :type entity_short_name: str
+        :param prov_short_name: In case of a provenance entity, the short name associated to the type
+         of the entity itself. An empty string otherwise.
+        :type prov_short_name: str
+        :param identifier: In case of a provenance entity, the counter value that identifies the relative
+          graph entity. The integer value '1' otherwise.
+        :type identifier: int
+        :raises ValueError: if ``identifier`` is less than or equal to zero.
+        :return: The requested counter value.
+        """
         if prov_short_name == "se":
-            file_path: str = self.get_prov_path(entity_short_name)
+            file_path: str = self._get_prov_path(entity_short_name)
         else:
-            file_path: str = self.get_info_path(entity_short_name)
+            file_path: str = self._get_info_path(entity_short_name)
         return self._read_number(file_path, identifier)[0]
 
     def increment_counter(self, entity_short_name: str, prov_short_name: str = "", identifier: int = 1) -> int:
+        """
+        It allows to increment the counter value of graph and provenance entities by one unit.
+
+        :param entity_short_name: The short name associated either to the type of the entity itself
+         or, in case of a provenance entity, to the type of the relative graph entity.
+        :type entity_short_name: str
+        :param prov_short_name: In case of a provenance entity, the short name associated to the type
+         of the entity itself. An empty string otherwise.
+        :type prov_short_name: str
+        :param identifier: In case of a provenance entity, the counter value that identifies the relative
+          graph entity. The integer value '1' otherwise.
+        :type identifier: int
+        :raises ValueError: if ``identifier`` is less than or equal to zero.
+        :return: The newly-updated (already incremented) counter value.
+        """
         if prov_short_name == "se":
-            file_path: str = self.get_prov_path(entity_short_name)
+            file_path: str = self._get_prov_path(entity_short_name)
         else:
-            file_path: str = self.get_info_path(entity_short_name)
+            file_path: str = self._get_info_path(entity_short_name)
         return self._add_number(file_path, identifier)
 
-    def get_info_path(self, short_name: str) -> str:
+    def _get_info_path(self, short_name: str) -> str:
         return self.info_dir + self.info_files[short_name]
 
-    def get_prov_path(self, short_name: str) -> str:
+    def _get_prov_path(self, short_name: str) -> str:
         return self.info_dir + self.prov_files[short_name]
 
-    def get_metadata_path(self, short_name: str, dataset_name: str) -> str:
+    def _get_metadata_path(self, short_name: str, dataset_name: str) -> str:
         return self.datasets_dir + dataset_name + os.sep + 'metadata_' + short_name + '.txt'
 
     def __initialize_file_if_not_existing(self, file_path: str):
@@ -85,9 +143,9 @@ class FilesystemCounterHandler(CounterHandler):
             os.makedirs(os.path.dirname(file_path))
 
         if not os.path.isfile(file_path):
-            with open(file_path, "wb") as file:
-                first_line: str = self.trailing_char * (self.initial_line_len - 1) + "\n"
-                file.write(first_line.encode("ascii"))
+            with open(file_path, 'wb') as file:
+                first_line: str = self._trailing_char * (self._initial_line_len - 1) + '\n'
+                file.write(first_line.encode('ascii'))
 
     def _read_number(self, file_path: str, line_number: int) -> Tuple[int, int]:
         if line_number <= 0:
@@ -98,12 +156,12 @@ class FilesystemCounterHandler(CounterHandler):
         cur_number: int = 0
         cur_line_len: int = 0
         try:
-            with open(file_path, "rb") as file:
+            with open(file_path, 'rb') as file:
                 cur_line_len = self._get_line_len(file)
                 line_offset = (line_number - 1) * cur_line_len
                 file.seek(line_offset)
-                line = file.readline(cur_line_len).decode("ascii")
-                cur_number = int(line.rstrip(self.trailing_char + "\n"))
+                line = file.readline(cur_line_len).decode('ascii')
+                cur_number = int(line.rstrip(self._trailing_char + '\n'))
         except ValueError:
             cur_number = 0
         except Exception as e:
@@ -125,11 +183,11 @@ class FilesystemCounterHandler(CounterHandler):
             self._increase_line_len(file_path, new_length=cur_number_len)
             cur_line_len = cur_number_len
 
-        with open(file_path, "r+b") as file:
+        with open(file_path, 'r+b') as file:
             line_offset: int = (line_number - 1) * cur_line_len
             file.seek(line_offset)
-            line: str = str(cur_number).ljust(cur_line_len - 1, self.trailing_char) + "\n"
-            file.write(line.encode("ascii"))
+            line: str = str(cur_number).ljust(cur_line_len - 1, self._trailing_char) + '\n'
+            file.write(line.encode('ascii'))
             file.seek(-cur_line_len, os.SEEK_CUR)
             self._fix_previous_lines(file, cur_line_len)
         return cur_number
@@ -150,11 +208,11 @@ class FilesystemCounterHandler(CounterHandler):
             self._increase_line_len(file_path, new_length=cur_number_len)
             cur_line_len = cur_number_len
 
-        with open(file_path, "r+b") as file:
+        with open(file_path, 'r+b') as file:
             line_offset: int = (line_number - 1) * cur_line_len
             file.seek(line_offset)
-            line: str = str(new_value).ljust(cur_line_len - 1, self.trailing_char) + "\n"
-            file.write(line.encode("ascii"))
+            line: str = str(new_value).ljust(cur_line_len - 1, self._trailing_char) + '\n'
+            file.write(line.encode('ascii'))
             file.seek(-cur_line_len, os.SEEK_CUR)
             self._fix_previous_lines(file, cur_line_len)
 
@@ -182,17 +240,17 @@ class FilesystemCounterHandler(CounterHandler):
         if new_length <= 0:
             raise ValueError("new_length must be a positive non-zero integer number!")
 
-        with open(file_path, "rb") as cur_file:
+        with open(file_path, 'rb') as cur_file:
             if self._get_line_len(cur_file) >= new_length:
                 raise ValueError("Current line length is greater than new_length!")
 
         fh, abs_path = mkstemp()
-        with os.fdopen(fh, "wb") as new_file:
-            with open(file_path, "rt", encoding="ascii") as old_file:
+        with os.fdopen(fh, 'wb') as new_file:
+            with open(file_path, 'rt', encoding='ascii') as old_file:
                 for line in old_file:
-                    number: str = line.rstrip(self.trailing_char + "\n")
-                    new_line: str = str(number).ljust(new_length - 1, self.trailing_char) + "\n"
-                    new_file.write(new_line.encode("ascii"))
+                    number: str = line.rstrip(self._trailing_char + '\n')
+                    new_line: str = str(number).ljust(new_length - 1, self._trailing_char) + '\n'
+                    new_file.write(new_line.encode('ascii'))
 
         # Copy the file permissions from the old file to the new file
         copymode(file_path, abs_path)
@@ -207,8 +265,8 @@ class FilesystemCounterHandler(CounterHandler):
         return (string[-1] == "\n") and ("\0" not in string[:-1])
 
     def _fix_previous_lines(self, file: BinaryIO, line_len: int) -> None:
-        if line_len < self.initial_line_len:
-            raise ValueError("line_len should be at least %d!" % self.initial_line_len)
+        if line_len < self._initial_line_len:
+            raise ValueError("line_len should be at least %d!" % self._initial_line_len)
 
         while file.tell() >= line_len:
             file.seek(-line_len, os.SEEK_CUR)
@@ -217,11 +275,24 @@ class FilesystemCounterHandler(CounterHandler):
                 break
             else:
                 file.seek(-line_len, os.SEEK_CUR)
-                fixed_line: str = (self.trailing_char * (line_len - 1)) + "\n"
+                fixed_line: str = (self._trailing_char * (line_len - 1)) + "\n"
                 file.write(fixed_line.encode("ascii"))
                 file.seek(-line_len, os.SEEK_CUR)
 
     def set_metadata_counter(self, new_value: int, entity_short_name: str, dataset_name: str) -> None:
+        """
+        It allows to set the counter value of metadata entities.
+
+        :param new_value: The new counter value to be set
+        :type new_value: int
+        :param entity_short_name: The short name associated either to the type of the entity itself.
+        :type entity_short_name: str
+        :param dataset_name: In case of a ``Dataset``, its name. Otherwise, the name of the relative dataset.
+        :type dataset_name: str
+        :raises ValueError: if ``new_value`` is a negative integer, ``dataset_name`` is None or
+          ``entity_short_name`` is not a known metadata short name.
+        :return: None
+        """
         if new_value < 0:
             raise ValueError("new_value must be a non negative integer!")
 
@@ -231,25 +302,45 @@ class FilesystemCounterHandler(CounterHandler):
         if entity_short_name not in self.metadata_short_names:
             raise ValueError("entity_short_name is not a known metadata short name!")
 
-        file_path: str = self.get_metadata_path(entity_short_name, dataset_name)
+        file_path: str = self._get_metadata_path(entity_short_name, dataset_name)
         return self._set_number(new_value, file_path, 1)
 
     def read_metadata_counter(self, entity_short_name: str, dataset_name: str) -> int:
+        """
+        It allows to read the counter value of metadata entities.
+
+        :param entity_short_name: The short name associated either to the type of the entity itself.
+        :type entity_short_name: str
+        :param dataset_name: In case of a ``Dataset``, its name. Otherwise, the name of the relative dataset.
+        :type dataset_name: str
+        :raises ValueError: if ``dataset_name`` is None or ``entity_short_name`` is not a known metadata short name.
+        :return: The requested counter value.
+        """
         if dataset_name is None:
             raise ValueError("dataset_name must be provided!")
 
         if entity_short_name not in self.metadata_short_names:
             raise ValueError("entity_short_name is not a known metadata short name!")
 
-        file_path: str = self.get_metadata_path(entity_short_name, dataset_name)
+        file_path: str = self._get_metadata_path(entity_short_name, dataset_name)
         return self._read_number(file_path, 1)[0]
 
     def increment_metadata_counter(self, entity_short_name: str, dataset_name: str) -> int:
+        """
+        It allows to increment the counter value of metadata entities by one unit.
+
+        :param entity_short_name: The short name associated either to the type of the entity itself.
+        :type entity_short_name: str
+        :param dataset_name: In case of a ``Dataset``, its name. Otherwise, the name of the relative dataset.
+        :type dataset_name: str
+        :raises ValueError: if ``dataset_name`` is None or ``entity_short_name`` is not a known metadata short name.
+        :return: The newly-updated (already incremented) counter value.
+        """
         if dataset_name is None:
             raise ValueError("dataset_name must be provided!")
 
         if entity_short_name not in self.metadata_short_names:
             raise ValueError("entity_short_name is not a known metadata short name!")
 
-        file_path: str = self.get_metadata_path(entity_short_name, dataset_name)
+        file_path: str = self._get_metadata_path(entity_short_name, dataset_name)
         return self._add_number(file_path, 1)
